@@ -14,7 +14,9 @@ Exports:
 
 *  ``ExitState`` class
 *  ``main`` function
+*  ``release_flow_main`` function
 """
 
+from ._release_flow import release_flow_main  # noqa: F401
 from .build_harness_group import main  # noqa: F401
 from .state import ExitState  # noqa: F401
