@@ -16,6 +16,7 @@ import click
 
 from build_harness._version import acquire_version
 
+from ._declarations import DEFAULT_PROJECT_PATH
 from .analysis import static_analysis
 from .bdd import bdd_acceptance_command
 from .bootstrap import install
@@ -25,8 +26,6 @@ from .state import CommandState
 from .unit_tests import unit_test
 from .wheel import package
 
-DEFAULT_PROJECT_PATH = "."
-
 
 @click.group()
 @click.pass_context
