@@ -86,7 +86,8 @@ def _publish_packages(
 @click.option(
     "--dryrun",
     default=False,
-    help="PEP-440 release id to apply to package. [default: do nothing]",
+    help="Run publishing steps without actually publishing artifacts. [default: "
+    "do nothing]",
     is_flag=True,
 )
 @click.option(
