@@ -19,6 +19,7 @@ from build_harness.commands.bootstrap import (
     DependencyInstallError,
     ExitState,
     ProjectDependencies,
+    PyprojecttomlError,
     VenvError,
     VenvPipError,
     _check_dependencies,
@@ -285,7 +286,7 @@ class TestInstallProjectDependencies:
             universal_newlines=True,
         )
 
-    def test_raises(self, mocker):
+    def test_install_raises(self, mocker):
         mock_dependencies = [
             "toml == 3.1.4",
             "flit >=2.0,<4",
@@ -538,6 +539,16 @@ class TestInstall:
             ]
         )
 
+    def test_bad_pyprojecttoml(self, click_runner, mocker):
+        mocker.patch(
+            "build_harness.commands.bootstrap.acquire_project_dependencies",
+            side_effect=PyprojecttomlError("Missing pyproject.toml file"),
+        )
+        result = click_runner.invoke(main, ["install"])
+
+        assert result.exit_code == ExitState.BAD_PYPROJECTTOML
+        assert "Missing pyproject.toml file" in result.output
+
     def test_fails(self, click_runner, mocker):
         mocker.patch(
             "build_harness.commands.bootstrap._install_project_dependencies",
